@@ -3,26 +3,26 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Parse the UCI Bach choral harmony data set
 
-our $VERSION = '0.0203';
+our $VERSION = '0.0204';
 
 use Moo;
 use strictures 2;
 use namespace::clean;
 
 use Text::CSV;
-use File::ShareDir 'dist_dir';
+use File::ShareDir qw/ dist_dir /;
 use List::Util qw/ any /;
 
 
 has data_file => (
     is      => 'ro',
-    default => sub { dist_dir('Music-BachChoralHarmony') . '/' .  'jsbach_chorals_harmony.data' },
+    default => sub { dist_dir('Music-BachChoralHarmony') . '/jsbach_chorals_harmony.data' },
 );
 
 
 has key_title => (
     is      => 'ro',
-    default => sub { dist_dir('Music-BachChoralHarmony') . '/' . 'jsbach_BWV_keys_titles.txt' },
+    default => sub { dist_dir('Music-BachChoralHarmony') . '/jsbach_BWV_keys_titles.txt' },
 );
 
 
@@ -109,12 +109,14 @@ sub search {
 
     if ( $args{id} ) {
         my @ids = split /\s+/, $args{id};
+
         for my $id ( @ids ) {
             push @results, { $id => $self->data->{$id} };
         }
     }
     elsif ( $args{key} ) {
         my @keys = split /\s+/, $args{key};
+
         for my $id ( keys %{ $self->data } ) {
             push @results, { $id => $self->data->{$id} }
                 if any { $_ eq $self->data->{$id}{key} } @keys;
@@ -129,7 +131,9 @@ sub search {
     elsif ( $args{notes} ) {
         my $and = $args{notes} =~ /&/ ? 1 : 0;
         my $re  = $and ? qr/\s*&\s*/ : qr/\s+/;
+
         my @notes = split $re, $args{notes};
+
         my %index = (
             'C'  => 0,
             'C#' => 1,
@@ -149,11 +153,15 @@ sub search {
             'Bb' => 10,
             'B'  => 11,
         );
+
         ID: for my $id ( keys %{ $self->data } ) {
             my %and_notes = ();
+
             for my $event ( @{ $self->data->{$id}{events} } ) {
                 my @bitstring = split //, $event->{notes};
+
                 my $i = 0;
+
                 for my $bit ( @bitstring ) {
                     if ( $bit ) {
                         if ( $and ) {
@@ -170,17 +178,22 @@ sub search {
                             }
                         }
                     }
+
                     $i++;
                 }
             }
+
             if ( keys %and_notes ) {
                 my %notes;
                 @notes{@notes} = undef;
+
                 my $i = 0;
+
                 for my $n ( keys %and_notes ) {
                     $i++
                         if exists $notes{$n};
                 }
+
                 push @results, { $id => $self->data->{$id} }
                     if $i == scalar keys %notes;
             }
@@ -197,11 +210,13 @@ sub _search_param {
 
     my $and = $param =~ /&/ ? 1 : 0;
     my $re  = $and ? qr/\s*&\s*/ : qr/\s+/;
+
     my %notes = ();
     @notes{ split $re, $param } = undef;
 
     ID: for my $id ( keys %{ $self->data } ) {
         my %and_notes = ();
+
         for my $event ( @{ $self->data->{$id}{events} } ) {
             if ( $and ) {
                 for my $note ( keys %notes ) {
@@ -217,12 +232,15 @@ sub _search_param {
                 }
             }
         }
+
         if ( keys %and_notes ) {
             my $i = 0;
+
             for my $n ( keys %and_notes ) {
                 $i++
                     if exists $notes{$n};
             }
+
             push @results, { $id => $self->data->{$id} }
                 if $i == scalar keys %notes;
         }
@@ -246,7 +264,7 @@ Music::BachChoralHarmony - Parse the UCI Bach choral harmony data set
 
 =head1 VERSION
 
-version 0.0203
+version 0.0204
 
 =head1 SYNOPSIS
 
@@ -256,10 +274,10 @@ version 0.0203
   my $songs = $bach->parse;
 
   # show all the song ids:
-  print Dumper [ keys %$songs ];
+  print Dumper [ sort keys %$songs ];
 
   # show all the song titles:
-  print Dumper [ map { $songs->{$_}{title} } keys %$songs ];
+  print Dumper [ map { $songs->{$_}{title} } sort keys %$songs ];
 
   $songs = $bach->search( id => '000106b_' );
   $songs = $bach->search( id => '000106b_ 000206b_' );
@@ -290,12 +308,11 @@ This module does a few simple things:
 4. It allows searching by ids, keys, notes, and chords.
 
 The BWV and titles were collected from an old Internet Archive of
-C<jsbchorales.net> and filled-in from C<bach-chorales.com>.  The keys were
-computed with a C<music21> python program and again filled-in from
-C<bach-chorales.com>.  Check out the links in the L</SEE ALSO> section
-for more information.
-
-See the distribution C<eg/> programs for usage examples.
+C<jsbchorales.net> and filled-in from L<https://bach-chorales.com/>.
+The keys were computed with a L<music21|https://web.mit.edu/music21/>
+python program, and if missing filled-in again from
+L<https://bach-chorales.com/>.  Check out the links in the
+L</SEE ALSO> section for more information.
 
 =head1 ATTRIBUTES
 
@@ -337,40 +354,33 @@ Create a new C<Music::BachChoralHarmony> object.
 Parse the B<data_file> and B<key_title> files into a B<data> hash
 reference of each song keyed by the song id.  Each song includes a BWV
 identifier, title, key and list of events.  The event list is made of
-hash references with keys for the notes bit string, bass note, the
-accent value and the resonating chord.
+hash references with a B<notes> bit string, B<bass> note, the
+B<accent> value and the resonating B<chord>.
 
 =head2 search
 
-  $songs = $bach->search( id => '000106b_' ); # Single song
-  $songs = $bach->search( id => '000106b_ 000206b_' ); # Two songs
-  $songs = $bach->search( key => 'C_M' );         # All C major key songs
-  $songs = $bach->search( key => 'C_M C_m' );     # All in C major and C minor keys
-  $songs = $bach->search( bass => 'C' );          # All with a C in the bass
-  $songs = $bach->search( bass => 'C D' );        # With a C or a D in the bass
-  $songs = $bach->search( bass => 'C & D' );      # With a C and a D in the bass
-  $songs = $bach->search( chord => 'C_M' );       # With a C major chord
-  $songs = $bach->search( chord => 'C_M D_m' );   # With C major or D minor chords
-  $songs = $bach->search( chord => 'C_M & D_m' ); # With both C major and D minor chords
-  $songs = $bach->search( notes => 'C E G' );     # With the notes C or E or G
-  $songs = $bach->search( notes => 'C & E & G' ); # With the notes C and E and G
+  $songs = $bach->search( $k => $v ); # As in the SYNOPSIS above
 
 Search the parsed result B<data> by song B<id>s, B<key>s, B<bass>
 notes, B<chord>s, or individual B<notes> and return an array reference
-of hash references:
+of hash references of the format:
 
   [ { $song_id => $song_data }, ... ],
 
 The B<id>, and B<key> can be searched by single or multiple values
-returning all songs that match.  Separate note names with a space
-character.
+returning all songs that match.  Note names must be separated with a
+space character.
 
 The B<bass>, B<chord>, and B<notes> can be searched either as C<or>
 (separating note names with a space character), or as inclusive C<and>
 (separating note names with an C<&> character).
 
+* The items to search for cannot be combined at this time.
+
 =head1 SEE ALSO
 
+The F<eg/*> and F<t/01-methods.t> files
+
 L<Moo>
 
 L<Text::CSV>
@@ -385,10 +395,10 @@ L<https://web.archive.org/web/20140515065053/http://www.jsbchorales.net/bwv.shtm
 
 L<http://www.bach-chorales.com/BachChorales.htm>
 
-L<http://web.mit.edu/music21/>
-
 L<https://github.com/ology/Bach-Chorales/blob/master/bin/key.py>
 
+L<https://github.com/ology/Bach-Chorales/blob/master/chorales.zip> are the collected MIDI files and PDF transcriptions.
+
 =head1 THANK YOU
 
 Dan Book (L<DBOOK|https://metacpan.org/author/DBOOK>) for the ShareDir clues.
